#include<windows.h>

class Foo;

int main(void) {
    return 0;
}
